==> AsposeCellsCloud-CellsApi-22.12.tar.gz: AsposeCellsCloud-CellsApi-22.12/lib/AsposeCellsCloud/Object/ImportStringArrayOption.pm <==
=begin comment

Copyright (c) 2022 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut


package AsposeCellsCloud::Object::ImportStringArrayOption;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use AsposeCellsCloud::Object::FileSource;
use AsposeCellsCloud::Object::ImportOption;

use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;
	
	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}
	
	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }
  
    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);
        
    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}



__PACKAGE__->class_documentation({description => '',
                                  class => 'ImportStringArrayOption',
                                  required => [], # TODO
}                                 );

__PACKAGE__->method_documentation({
    'source' => {
    	datatype => 'FileSource',
    	base_name => 'Source',
    	description => '',
    	format => '',
    	read_only => '',
    		},
    'import_data_type' => {
    	datatype => 'string',
    	base_name => 'ImportDataType',
    	description => '',
    	format => '',
    	read_only => '',
    		},
    'destination_worksheet' => {
    	datatype => 'string',
    	base_name => 'DestinationWorksheet',
    	description => '',
    	format => '',
    	read_only => '',
    		},
    'is_insert' => {
    	datatype => 'boolean',
    	base_name => 'IsInsert',
    	description => '',
    	format => '',
    	read_only => '',
    		},
    'data' => {
    	datatype => 'ARRAY[string]',
    	base_name => 'Data',
    	description => '',
    	format => '',
    	read_only => '',
    		},
    'is_vertical' => {
    	datatype => 'boolean',
    	base_name => 'IsVertical',
    	description => '',
    	format => '',
    	read_only => '',
    		},
    'first_row' => {
    	datatype => 'int',
    	base_name => 'FirstRow',
    	description => '',
    	format => '',
    	read_only => '',
    		},
    'first_column' => {
    	datatype => 'int',
    	base_name => 'FirstColumn',
    	description => '',
    	format => '',
    	read_only => '',
    		},
});

__PACKAGE__->swagger_types( {
    'source' => 'FileSource',
    'import_data_type' => 'string',
    'destination_worksheet' => 'string',
    'is_insert' => 'boolean',
    'data' => 'ARRAY[string]',
    'is_vertical' => 'boolean',
    'first_row' => 'int',
    'first_column' => 'int'
} );

__PACKAGE__->attribute_map( {
    'source' => 'Source',
    'import_data_type' => 'ImportDataType',
    'destination_worksheet' => 'DestinationWorksheet',
    'is_insert' => 'IsInsert',
    'data' => 'Data',
    'is_vertical' => 'IsVertical',
    'first_row' => 'FirstRow',
    'first_column' => 'FirstColumn'
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;

==> AsposeCellsCloud-CellsApi-23.6.tar.gz: AsposeCellsCloud-CellsApi-23.6/lib/AsposeCellsCloud/Object/ImportStringArrayOption.pm <==
=begin comment

Copyright (c) 2023 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut

package AsposeCellsCloud::Object::ImportStringArrayOption;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;
use AsposeCellsCloud::Object::FileSource;
use AsposeCellsCloud::Object::ImportOption; 


use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;

	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}

	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => '',
                                  class => 'ImportStringArrayOption',
                                  required => [], # TODO
}                                 );


__PACKAGE__->method_documentation({
     'first_row' => {
     	datatype => 'int',
     	base_name => 'FirstRow',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'first_column' => {
     	datatype => 'int',
     	base_name => 'FirstColumn',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'is_vertical' => {
     	datatype => 'boolean',
     	base_name => 'IsVertical',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'data' => {
     	datatype => 'ARRAY[string]',
     	base_name => 'Data',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'destination_worksheet' => {
     	datatype => 'string',
     	base_name => 'DestinationWorksheet',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'is_insert' => {
     	datatype => 'boolean',
     	base_name => 'IsInsert',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'import_data_type' => {
     	datatype => 'string',
     	base_name => 'ImportDataType',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'source' => {
     	datatype => 'FileSource',
     	base_name => 'Source',
     	description => '',
     	format => '',
     	read_only => '',
     		},    
});

__PACKAGE__->swagger_types( {
    'first_row' => 'int',
    'first_column' => 'int',
    'is_vertical' => 'boolean',
    'data' => 'ARRAY[string]',
    'destination_worksheet' => 'string',
    'is_insert' => 'boolean',
    'import_data_type' => 'string',
    'source' => 'FileSource' 
} );

__PACKAGE__->attribute_map( {
    'first_row' => 'FirstRow',
    'first_column' => 'FirstColumn',
    'is_vertical' => 'IsVertical',
    'data' => 'Data',
    'destination_worksheet' => 'DestinationWorksheet',
    'is_insert' => 'IsInsert',
    'import_data_type' => 'ImportDataType',
    'source' => 'Source' 
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;
